@@ -22,6 +22,8 @@
 #define _FIND_H_
 
 void set_accept_dotfiles();
+int skipthisfile(const char *);
+int issourcefile(const char *);
 void find_open(const char *);
 void find_open_filelist(const char *, const char *);
 char *find_read(void);
