@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998, 1999, 2000, 2002, 2003
+ * Copyright (c) 1998, 1999, 2000, 2002, 2003, 2008
  *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
@@ -29,6 +29,7 @@
 #include <strings.h>
 #endif
 
+#include "die.h"
 #include "gparam.h"
 #include "strlimcpy.h"
 #include "token.h"
@@ -215,8 +216,14 @@ nexttoken(const char *interested, int (*reserved)(const char *, int))
 				if (tmp == '\"' || tmp == '\'')
 					continue;
 			}
-			for (*p++ = c; (c = nextchar()) != EOF && (c & 0x80 || isalnum(c) || c == '_'); *p++ = c)
-				;
+			for (*p++ = c; (c = nextchar()) != EOF && (c & 0x80 || isalnum(c) || c == '_');) {
+				if (tlen < sizeof(token))
+					*p++ = c;
+			}
+			if (tlen == sizeof(token)) {
+				warning("symbol name is too long. (Ignored)[+%d %s]", lineno, curfile);
+				continue;
+			}
 			*p = 0;
 	
 			if (c != EOF)
@@ -257,13 +264,42 @@ peekc(int immediate)
 {
 	int c;
 	long pos;
+    int comment = 0;
 
 	if (cp != NULL) {
 		if (immediate)
 			c = nextchar();
 		else
-			while ((c = nextchar()) != EOF && c != '\n' && isspace(c))
-				;
+            while ((c = nextchar()) != EOF && c != '\n') {
+                if (c == '/') {			/* comment */
+                    if ((c = nextchar()) == '/') {
+                        while ((c = nextchar()) != EOF)
+                            if (c == '\n') {
+                                pushbackchar();
+                                break;
+                            }
+                    } else if (c == '*') {
+                        comment = 1;
+                        while ((c = nextchar()) != EOF) {
+                            if (c == '*') {
+                                if ((c = nextchar()) == '/')
+                                {
+                                    comment = 0;
+                                    break;
+                                }
+                            }
+                            else if (c == '\n')
+                            {
+                                pushbackchar();
+                                break;
+                            }
+                        }
+                    } else
+                        pushbackchar();
+                }
+                else if (!isspace(c))
+                    break;
+            }
 		if (c != EOF)
 			pushbackchar();
 		if (c != '\n' || immediate)
@@ -273,12 +309,50 @@ peekc(int immediate)
 	if (immediate)
 		c = getc(ip);
 	else
-		while ((c = getc(ip)) != EOF && isspace(c))
-			;
+        while ((c = getc(ip)) != EOF) {
+            if (comment) {
+                while ((c = getc(ip)) != EOF) {
+                    if (c == '*') {
+                        if ((c = getc(ip)) == '/')
+                        {
+                            comment = 0;
+                            break;
+                        }
+                    }
+                }
+            }
+            else if (c == '/') {			/* comment */
+                if ((c = getc(ip)) == '/') {
+                    while ((c = getc(ip)) != EOF)
+                        if (c == '\n') {
+                            break;
+                        }
+                } else if (c == '*') {
+                    while ((c = getc(ip)) != EOF) {
+                        if (c == '*') {
+                            if ((c = getc(ip)) == '/')
+                                break;
+                        }
+                    }
+                } else
+                    break;
+            }
+            else if (!isspace(c))
+                break;
+        }
+
 	(void)fseek(ip, pos, SEEK_SET);
 
 	return c;
 }
+/*
+ * throwaway_nextchar: throw away next character
+ */
+void
+throwaway_nextchar()
+{
+	nextchar();
+}
 /*
  * atfirst_exceptspace: return if current position is the first column
  *			except for space.
